@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna.php 691 2009-01-17 18:25:37Z mumumu-org $
+ *  @version    $Id: 9d6c2da5a9d4e978ea8fa675db56445d4ff26e35 $
  */
 
 //
@@ -24,6 +24,12 @@ if (substr(PHP_OS, 0, 3) == 'WIN'
 } elseif (!defined('ETHNA_OS_WINDOWS')) {
     define('ETHNA_OS_WINDOWS', false);
 }
+//  PHP 5.1.0 以降向けの変更
+//  date.timezone が設定されていないと
+//  E_STRICT|WARNING が発生する
+if (!ini_get('date.timezone')) {
+    ini_set('date.timezone', 'Asia/Tokyo');
+}
 
 if (!defined('PATH_SEPARATOR')) {
     if (ETHNA_OS_WINDOWS) {
@@ -45,7 +51,7 @@ if (!defined('DIRECTORY_SEPARATOR')) {
 }
 
 /** バージョン定義 */
-define('ETHNA_VERSION', '2.5.0-preview3');
+define('ETHNA_VERSION', '2.6.0-beta2');
 
 /**
  * ダミーのエラーモード
@@ -56,41 +62,46 @@ define('ETHNA_ERROR_DUMMY', 'dummy');
 /** Ethnaベースディレクトリ定義 */
 define('ETHNA_BASE', dirname(__FILE__));
 
-require_once ETHNA_BASE . '/class/Ethna_ActionClass.php';
-require_once ETHNA_BASE . '/class/Ethna_ActionError.php';
-require_once ETHNA_BASE . '/class/Ethna_ActionForm.php';
-require_once ETHNA_BASE . '/class/Ethna_AppManager.php';
-require_once ETHNA_BASE . '/class/Ethna_AppObject.php';
-require_once ETHNA_BASE . '/class/Ethna_AppSQL.php';
-require_once ETHNA_BASE . '/class/Ethna_AppSearchObject.php';
-require_once ETHNA_BASE . '/class/Ethna_Backend.php';
-require_once ETHNA_BASE . '/class/Ethna_CacheManager.php';
-require_once ETHNA_BASE . '/class/Ethna_Config.php';
-require_once ETHNA_BASE . '/class/Ethna_Controller.php';
-require_once ETHNA_BASE . '/class/Ethna_ClassFactory.php';
-require_once ETHNA_BASE . '/class/Ethna_DB.php';
-require_once ETHNA_BASE . '/class/Ethna_Error.php';
-require_once ETHNA_BASE . '/class/Ethna_Filter.php';
-require_once ETHNA_BASE . '/class/Ethna_Handle.php';
-require_once ETHNA_BASE . '/class/Ethna_I18N.php';
-require_once ETHNA_BASE . '/class/Ethna_Logger.php';
-require_once ETHNA_BASE . '/class/Ethna_MailSender.php';
-require_once ETHNA_BASE . '/class/Ethna_Session.php';
-require_once ETHNA_BASE . '/class/Ethna_Generator.php';
-require_once ETHNA_BASE . '/class/Ethna_UrlHandler.php';
-require_once ETHNA_BASE . '/class/Ethna_Util.php';
-require_once ETHNA_BASE . '/class/Ethna_ViewClass.php';
-require_once ETHNA_BASE . '/class/View/Ethna_View_List.php';
-require_once ETHNA_BASE . '/class/Ethna_Plugin.php';
-require_once ETHNA_BASE . '/class/Ethna_Renderer.php';
-require_once ETHNA_BASE . '/class/CLI/Ethna_CLI_ActionClass.php';
+require_once ETHNA_BASE . '/class/ActionClass.php';
+require_once ETHNA_BASE . '/class/ActionError.php';
+require_once ETHNA_BASE . '/class/ActionForm.php';
+require_once ETHNA_BASE . '/class/AppManager.php';
+require_once ETHNA_BASE . '/class/AppObject.php';
+require_once ETHNA_BASE . '/class/AppSQL.php';
+require_once ETHNA_BASE . '/class/AppSearchObject.php';
+require_once ETHNA_BASE . '/class/Backend.php';
+require_once ETHNA_BASE . '/class/CacheManager.php';
+require_once ETHNA_BASE . '/class/Config.php';
+require_once ETHNA_BASE . '/class/Controller.php';
+require_once ETHNA_BASE . '/class/ClassFactory.php';
+require_once ETHNA_BASE . '/class/DB.php';
+require_once ETHNA_BASE . '/class/Error.php';
+require_once ETHNA_BASE . '/class/Filter.php';
+require_once ETHNA_BASE . '/class/Handle.php';
+require_once ETHNA_BASE . '/class/I18N.php';
+require_once ETHNA_BASE . '/class/Logger.php';
+require_once ETHNA_BASE . '/class/MailSender.php';
+require_once ETHNA_BASE . '/class/Session.php';
+require_once ETHNA_BASE . '/class/Generator.php';
+require_once ETHNA_BASE . '/class/UrlHandler.php';
+require_once ETHNA_BASE . '/class/Util.php';
+require_once ETHNA_BASE . '/class/ViewClass.php';
+require_once ETHNA_BASE . '/class/View/Json.php';
+require_once ETHNA_BASE . '/class/View/Redirect.php';
+require_once ETHNA_BASE . '/class/View/403.php';
+require_once ETHNA_BASE . '/class/View/404.php';
+require_once ETHNA_BASE . '/class/View/500.php';
+require_once ETHNA_BASE . '/class/View/List.php';
+require_once ETHNA_BASE . '/class/Plugin.php';
+require_once ETHNA_BASE . '/class/Renderer.php';
+require_once ETHNA_BASE . '/class/CLI/ActionClass.php';
 
 if (extension_loaded('soap')) {
-    require_once ETHNA_BASE . '/class/SOAP/Ethna_SOAP_ActionForm.php';
-    require_once ETHNA_BASE . '/class/SOAP/Ethna_SOAP_Gateway.php';
-    require_once ETHNA_BASE . '/class/SOAP/Ethna_SOAP_GatewayGenerator.php';
-    require_once ETHNA_BASE . '/class/SOAP/Ethna_SOAP_Util.php';
-    require_once ETHNA_BASE . '/class/SOAP/Ethna_SOAP_WsdlGenerator.php';
+    require_once ETHNA_BASE . '/class/SOAP/ActionForm.php';
+    require_once ETHNA_BASE . '/class/SOAP/Gateway.php';
+    require_once ETHNA_BASE . '/class/SOAP/GatewayGenerator.php';
+    require_once ETHNA_BASE . '/class/SOAP/Util.php';
+    require_once ETHNA_BASE . '/class/SOAP/WsdlGenerator.php';
 }
 
 /** ゲートウェイ: WWW */
@@ -298,10 +309,13 @@ define('E_PLUGIN_NOTFOUND', 196);
 /** エラーコード: プラグインエラー(その他) */
 define('E_PLUGIN_GENERAL', 197);
 
+/** PHP 5との互換保持定義 */
 if (defined('E_STRICT') == false) {
-    /** PHP 5との互換保持定義 */
     define('E_STRICT', 2048);
 }
+if (defined('E_DEPRECATED') == false) {
+    define('E_DEPRECATED', 8192);
+}
 
 /** Ethnaグローバル変数: エラーコールバック関数 */
 $GLOBALS['_Ethna_error_callback_list'] = array();
@@ -331,7 +345,7 @@ class Ethna
      *                を含む場合のみ TRUEを返します。
      *  @static
      */
-    function isError($data, $msgcode = NULL)
+    public static function isError($data, $msgcode = NULL)
     {
         if (!is_object($data)) {
             return false;
@@ -358,7 +372,7 @@ class Ethna
      *  @param  int     $code               エラーコード
      *  @static
      */
-    function &raiseError($message, $code = E_GENERAL)
+    public static function raiseError($message, $code = E_GENERAL)
     {
         $userinfo = null;
         if (func_num_args() > 2) {
@@ -379,7 +393,7 @@ class Ethna
      *  @param  int     $code               エラーコード
      *  @static
      */
-    function &raiseWarning($message, $code = E_GENERAL)
+    public static function raiseWarning($message, $code = E_GENERAL)
     {
         $userinfo = null;
         if (func_num_args() > 2) {
@@ -401,7 +415,7 @@ class Ethna
      *  @param  int     $code               エラーコード
      *  @static
      */
-    function &raiseNotice($message, $code = E_GENERAL)
+    public static function raiseNotice($message, $code = E_GENERAL)
     {
         $userinfo = null;
         if (func_num_args() > 2) {
@@ -422,7 +436,7 @@ class Ethna
      *  @param  mixed   string:コールバック関数名 array:コールバッククラス(名|オブジェクト)+メソッド名
      *  @static
      */
-    function setErrorCallback($callback)
+    public static function setErrorCallback($callback)
     {
         $GLOBALS['_Ethna_error_callback_list'][] = $callback;
     }
@@ -433,7 +447,7 @@ class Ethna
      *  @access public
      *  @static
      */
-    function clearErrorCallback()
+    public static function clearErrorCallback()
     {
         $GLOBALS['_Ethna_error_callback_list'] = array();
     }
@@ -445,7 +459,7 @@ class Ethna
      *  @param  object  Ethna_Error     Ethna_Errorオブジェクト
      *  @static
      */
-    function handleError(&$error)
+    public static function handleError(&$error)
     {
         for ($i = 0; $i < count($GLOBALS['_Ethna_error_callback_list']); $i++) {
             $callback =& $GLOBALS['_Ethna_error_callback_list'][$i];
@@ -466,4 +480,3 @@ class Ethna
 }
 // }}}
 
-?>
